Enum pushrod::core::callbacks::CallbackEvent

source ·
pub enum CallbackEvent {
Show 16 variants MouseEntered { widget_id: i32, }, MouseExited { widget_id: i32, }, MouseScrolled { widget_id: i32, point: Point, }, MouseMoved { widget_id: i32, point: Point, }, KeyPressed { widget_id: i32, key: Key, state: ButtonState, }, WindowResized { size: Size, }, WindowFocused { flag: bool, }, MouseButtonDown { widget_id: i32, button: Button, }, MouseButtonUpInside { widget_id: i32, button: Button, }, MouseButtonUpOutside { widget_id: i32, button: Button, }, WidgetClicked { widget_id: i32, button: Button, }, WidgetSelected { widget_id: i32, button: Button, selected: bool, }, WidgetMoved { widget_id: i32, point: Point, }, WidgetResized { widget_id: i32, size: Size, }, TimerTriggered { widget_id: i32, }, UnselectRadioButtons { widget_id: i32, group_id: i32, },
}
These are the different types of events that can be triggered. Any other callback events should be extended in this enum definition.

Variants



MouseEntered

Indicates a mouse entered the bounds of a Widget. Contains the ID of the Widget that was affected.

Fields

widget_id: i32


MouseExited

Indicates a mouse exited the bounds of a Widget. Contains the ID of the Widget that was affected.

Fields

widget_id: i32


MouseScrolled

Indicates that the scroll wheel was moved inside a Widget. Contains the ID of the Widget that had the mouse scroll action, and the point in the direction of the scroll, along with the amount of points the mouse scroll moved.

Fields

widget_id: i32
point: Point


MouseMoved

Indicates that a mouse moved within the bounds of a Widget. Contains the ID of the Widget that was affected.

Fields

widget_id: i32
point: Point


KeyPressed

Indicates that a keyboard key was pressed/released inside the bounds of a Widget. Contains the ID of the Widget that received the keypress, along with the Key value, and any associated Button modifier states.

Fields

widget_id: i32
key: Key


WindowResized

Indicates that the main application window was resized. Contains the Size of the new bounds.

Fields

size: Size


WindowFocused

Indicates whether or not focus was gained or lost for the main application. Contains a boolean flag indicating focus: true is focused, false if lost.

Fields

flag: bool


MouseButtonDown

Indicates that a mouse button was pressed within the bounds of a Widget. Contains the ID of the Widget, along with the Button that was clicked.

Fields

widget_id: i32
button: Button


MouseButtonUpInside

Indicates that a mouse button was released within the bounds of a Widget. Contains the ID of the Widget, along with the Button that was released.

Fields

widget_id: i32
button: Button


MouseButtonUpOutside

Indicates that a mouse button was released outside of the bounds of a Widget. Contains the ID of the Widget, along with the Button that was released.

Fields

widget_id: i32
button: Button


WidgetClicked

Indicates that a mouse button triggered a click action within a Widget. Contains the ID of the Widget, along with the Button that was used to indicate the click action.

Fields

widget_id: i32
button: Button


WidgetSelected

Indicates that a Widget’s selected state has been toggled. Contains the ID of the Widget that was toggled, along with the mouse Button that was clicked, and the final selected state of the widget.

Fields

widget_id: i32
button: Button
selected: bool


WidgetMoved

Indicates that a Widget’s position has been moved either through physical interaction, or through a LayoutManager repositioning. Contains the ID of the Widget that moved, along with its new position as a Point.

Fields

widget_id: i32
point: Point


WidgetResized

Indicates that a Widget’s Size has changed. Contains the ID of the Widget, along with the new Size of the Widget.

Fields

widget_id: i32
size: Size


TimerTriggered

Indicates that a timer timeout has been triggered. Contains the ID of the Widget that was affected.

Fields

widget_id: i32


UnselectRadioButtons

Indicates that a group of RadioButtonWidget objects has been deselected. Contains the ID of the Widget that was unselected, along with the group ID.

Fields

widget_id: i32
group_id: i32