[][src]Module pushrod::core::horizontal_layout_manager

This provides a HorizontalLayoutManager object, which accepts Widget objects, and resizes and repositions them according to the width of the manager. Widgets are repositioned in the HorizontalLayoutManager's top level widget equally.

Structs

HorizontalLayoutManager