[][src]Module pushrod::core::layout_manager

This provides a layout manager to the WidgetStore, which contains a list of known widgets by ID and their point offsets within the layouts.

Structs

LayoutManagerCoordinates

This structure is sent to the LayoutManager at the time do_layout is called. This structure contains the layout of all of the Widgets by origin, the sizes of each of the Widgets, and their positions relative to the layout manager. The widget_positions do not need to be actual positions in points - they can be used to denote the positions within the layout they are to occur - for instance, 0x0, 0x1, 1x0 and 1x1 in a layout, if the layout were a grid layout.

LayoutManagerPadding

This class defines the spacing rules and the padding for the layout manager. The layout manager must take the rules and honor it during the layout process.

Traits

LayoutManager

Describes the behavior of a LayoutManager. Layout Managers do not actually manage any Widget objects by themselves, they only apply the rules of the LayoutManagerPadding coordinates, and the size of the LayoutManager that is available.