[][src]Struct pushrod::core::layout_manager::LayoutManagerPadding

pub struct LayoutManagerPadding {
    pub left: i32,
    pub right: i32,
    pub top: i32,
    pub bottom: i32,
    pub spacing: i32,
}

This class defines the spacing rules and the padding for the layout manager. The layout manager must take the rules and honor it during the layout process.

Fields

left: i32right: i32top: i32bottom: i32spacing: i32