[][src]Enum pushrod::event::event::PushrodEvent

pub enum PushrodEvent {
    MouseEvent {
        point: Point,
    },
    MouseDownEvent {
        button: MouseButton,
    },
    MouseUpEvent {
        button: MouseButton,
    },
    MouseScrollEvent {
        point: Point,
    },
}

Enumeration types for different PushrodEvents, translated from the underlying OS.

Variants

MouseEvent

Mouse event contains a point to where the mouse was moved.

Fields of MouseEvent

point: Point
MouseDownEvent

Contains the button that was pressed.

Fields of MouseDownEvent

button: MouseButton
MouseUpEvent

COntains the button that was released.

Fields of MouseUpEvent

button: MouseButton
MouseScrollEvent

Contains the direction in which the mouse scroll event took place. X movement in a positive direction indicates movement to the right, where negative is to the left. Y movement in a positive direction indicates downward movement, negative is upward.

Fields of MouseScrollEvent

point: Point