render is the core rendering/event loop portion of Pushrod.
| callbacks | This is the Callbacks mechanism for each Widget, providing a way to perform a function when
an action is intercepted (ie. mouse enter, exit, move, etc.)
|
| engine | This is the Engine that is used to dispatch events from the screen to a corresponding list
of Widgets in a Window. This is the main event loop.
|
| widget | This is the Widget and BaseWidget definitions for Widget objects to be defined by the
pushrod project, and other crates that may define or create their own Widgets.
|
| widget_cache | This is the caching object that stores a list of Widgets that the Pushrod engine manages.
|
| widget_config | This is a configuration object that stores information about Widgets.
|