[−][src]Module pushrod::render::engine
This is the Engine that is used to dispatch events from the screen to a corresponding list
of Widgets in a Window. This is the main event loop.
Structs
| Engine | This is a storage container for the Pushrod event engine. |
Type Definitions
| OnExitCallbackType | This function is called when when the application requests to quit. It accepts the currently
running engine, and the return value will indicate whether or not to quit. Returning a |