Module layout

Module layout 

This is a layout manager description module, describing rules for Layout managers to be used in the system, and having Widgets added to them.

Structs

LayoutPosition
This is a structure that describes the position of a Widget within its Layout. X and Y coordinates are not given as physical positions on the screen, rather, their position in the Layout matrix.

Traits

Layout
This is a Layout trait that is used by the Engine service, which stores a list of Widgets, their positions (based on matrix coordinates), and an entry point to trigger the layout compute action.