pub struct LayoutPosition {
pub x: i32,
pub y: i32,
}Expand description
This is a structure that describes the position of a Widget within its Layout. X and
Y coordinates are not given as physical positions on the screen, rather, their position in the
Layout matrix.
Fields
x: i32y: i32Implementations