[][src]Trait pushrod::render::layout::Layout

pub trait Layout {
    fn add_widget(&mut self, _widget_id: i32, _widget_position: LayoutPosition);
fn do_layout(&mut self, _widgets: &[WidgetContainer]); }

This is a Layout trait that is used by the Engine service, which stores a list of Widgets, their positions (based on matrix coordinates), and an entry point to trigger the layout compute action.

Required methods

fn add_widget(&mut self, _widget_id: i32, _widget_position: LayoutPosition)

Adds a Widget by ID to the Layout manager, given its LayoutPosition, as a position marker in the manager.

fn do_layout(&mut self, _widgets: &[WidgetContainer])

Performs a layout, applying the WidgetContainer list at the time, so that referenced Widgets can be adjusted as necessary.

Loading content...

Implementors

Loading content...