[−][src]Struct pushrod::render::layout_cache::LayoutCache
This is a container object that stores a Vec of LayoutContainer objects for its cache.
Methods
impl LayoutCache[src]
This is the implementation of the LayoutCache.
pub fn new() -> Self[src]
pub fn add_layout(&mut self, layout: Box<dyn Layout>) -> i32[src]
Adds a Box<Layout> to the Layout stack.
pub fn get_layout_by_id(&mut self, id: i32) -> &mut LayoutContainer[src]
Retrieves a &mut LayoutContainer object by its ID.
pub fn get_layout_cache(&self) -> &[LayoutContainer][src]
Retrieves a borrowed slice of the LayoutContainer cache that can be sent to callbacks.
pub fn do_layout(&self, widgets: &[WidgetContainer])[src]
Performs the do_layout call on Layout objects only if their needs_layout flag is set
to true.