LayoutContainer

Struct LayoutContainer 

pub struct LayoutContainer {
    pub layout: RefCell<Box<dyn Layout>>,
    /* private fields */
}
This is a container object that stores a Layout object, and its ID.

Fields

layout: RefCell<Box<dyn Layout>>

Implementations

Source

impl LayoutContainer

This is an implementation that allows for creation of a LayoutContainer.

pub fn new(layout: Box<dyn Layout>, layout_id: i32) -> Self

Creates a new LayoutContainer-wrapped Layout object.

pub fn get_layout_id(&self) -> i32

Retrieves the current layout ID.