Module texture_store

Module texture_store 

This is a store used by Widgets for drawing against. Once the drawing is complete, the Texture stored within is used for blitting to the screen.

Structs

TextureStore
This is a store used by the TextureStore.