[−][src]Struct pushrod::render::texture_store::TextureStore
This is a store used by the TextureStore.
Methods
impl TextureStore[src]
This is a TextureStore that is used by Widgets to draw against. It serves as a GPU-based
Texture store that can be changed at any time during the drawing loop.
pub fn get_mut_ref(&mut self) -> &mut Texture[src]
Retrieves a &mut Texture reference to the stored Texture object.
Example use:
c.with_texture_canvas(texture_store.get_mut_ref(), |texture| { texture.set_draw_color(base_color); texture.clear(); texture.set_draw_color(border_color); texture .draw_rect(Rect::new(0, 0, 200, 200)) .unwrap(); }) .unwrap();
pub fn get_optional_ref(&mut self) -> Option<&Texture>[src]
Retrieves a Option<&Texture> object for the Texture object store. Use this as a shortcut
to the Widget's return values (see BaseWidget for reference.)
pub fn create_or_resize_texture(
&mut self,
c: &mut Canvas<Window>,
width: u32,
height: u32
)[src]
&mut self,
c: &mut Canvas<Window>,
width: u32,
height: u32
)
This is used to create a new Texture object that can be drawn against. If the Widget is
ever redrawn, this function will automatically generate a new Texture to draw against, and
destroy the previously stored Texture. If any changes are observed when calling this
function (ie. the width changes, height changes, or the store is lost), it is regenerated.