Module widget

Module widget 

This is the Widget and BaseWidget definitions for Widget objects to be defined by the pushrod project, and other crates that may define or create their own Widgets.

Structs

BaseWidget
This is an example top-level Widget object that is used to draw a background and a border of specified colors. COLOR_BASE determines the background fill color, and the COLOR_BORDER determines the color of the border. The width of the border is controlled by the get_config().border_width property.

Traits

Widget
This trait is shared by all Widget objects that have a presence on the screen. Functions that must be implemented are documented in the trait.