This is a configuration object that stores information about Widgets.
Structs
- Padding
Constraint - This struct stores padding constraints.
- Widget
Config - This is the store for the
WidgetConfig, which eachWidgetobject needs. This stores information about theWidget. It currently contains the point of origin, size, aHashMapof differentColors, a border width, and an invalidation flag.
Enums
- Compass
Position - This enum is used by the
ImageWidget, which controls the positioning of the image being rendered within the bounds of theWidget. - Config
- Configuration object type - allows configurations to be set using
Piston,Pushrod, or native types.
Constants
- CONFIG_
BORDER_ WIDTH Widgetconfiguration that stores the display border in pixels. This is stored as aConfig::Numericvalue.- CONFIG_
COLOR_ BASE WidgetBaseColorkey forcolorsHashMap. This is the base fill color of aWidgetthat is in an unselected state. This stored as aConfig::Color.- CONFIG_
COLOR_ BORDER WidgetBorderColorkey forcolorsHashMap. This should be used for the color of the border, if theWidgetdraws a border. This stored as aConfig::Color.- CONFIG_
COLOR_ HOVER WidgetHoverColorkey forcolorsHashMap. This is the base fill color of aWidgetthat has a mouse hovering over the top of theWidget, or when amouse_enteredevent is triggered. This is optional; theWidgetdoes not need to honor this color if it does not support a hover state. This stored as aConfig::Color.- CONFIG_
COLOR_ SECONDARY WidgetSecondaryColorkey forcolorsHashMap. This is the color theWidgetshould display for any secondary properties, such as a fill color for a progress widget, a spinner, etc. This stored as aConfig::Color.- CONFIG_
COLOR_ SELECTED WidgetSelectedColorkey forcolorsHashMap. This is the color theWidgetshould display when in selected state. This stored as aConfig::Color.- CONFIG_
COLOR_ TEXT WidgetTextColorkey forcolorsHashMap. This should be the color for the text being displayed inside theWidget. This stored as aConfig::Color.- CONFIG_
FONT_ SIZE TextWidgetfont size control. This is stored as aConfig::Numericvalue.- CONFIG_
IMAGE_ POSITION Widgetimage position direction, controls the position of anImagewithin the bounds of aWidget. This is stored as aConfig::CompassPositionvalue.- CONFIG_
ORIGIN Widgetconfiguration to store its origin on the screen. This is aConfig::Pointsobject in the config.- CONFIG_
SELECTED_ STATE PushButtonWidgetselected state. This is stored as aConfig::Togglevalue.- CONFIG_
SIZE Widgetconfiguration that stores the size of theWidget. This is aConfig::Sizeobject in the config.- CONFIG_
TEXT Widgettext store, used to display text on the screen. This is stored as aConfig::Textvalue.