pub enum Config {
Points(Points),
Size(Size),
Color(Color),
Numeric(i32),
Text(String),
Toggle(bool),
CompassPosition(CompassPosition),
PaddingConstraint(PaddingConstraint),
}Expand description
Configuration object type - allows configurations to be set using Piston, Pushrod, or
native types.
Variants
Points(Points)
This stores a Points type.
Size(Size)
This stores a Size type.
Color(Color)
This stores a Color.
Numeric(i32)
This stores a numeric value in the form of an i32 value.
Text(String)
This stores a String of text.
Toggle(bool)
This stores a true/false boolean flag.
CompassPosition(CompassPosition)
This stores a ComapssPosition.
PaddingConstraint(PaddingConstraint)
This stores a PaddingConstraint.