[][src]Struct pushrod::widget::box_widget::BoxWidget

pub struct BoxWidget { /* fields omitted */ }

A BoxWidget is a CanvasWidget with a bounding box. Takes two additional options:

  • CONFIG_BORDER_WIDTH specifies the width of the border to be drawn in pixels.
  • CONFIG_BORDER_COLOR specifies the color of the border to be drawn.

Methods

impl BoxWidget[src]

pub fn new() -> Self[src]

Constructor.