Struct pushrod::widget::checkbox_widget::CheckboxWidget
source · pub struct CheckboxWidget { /* private fields */ }Expand description
Draws a box with a toggleable checkbox, and text next to it.
Implementations
sourceimpl CheckboxWidget
impl CheckboxWidget
sourcepub fn new(
font_name: String,
text: String,
font_size: u32,
justify: TextJustify,
selected: bool,
) -> Self
pub fn new( font_name: String, text: String, font_size: u32, justify: TextJustify, selected: bool, ) -> Self
Constructor. Requires the name of the font, the text to display, the image name to display, the size of the font,
and the font justification when rendered. Images are loaded from the assets/ directory.
Examples found in repository?
examples/simple.rs (lines 880-886)
879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925
fn add_debugging(&mut self) {
let mut check_widget = CheckboxWidget::new(
"assets/OpenSans-Regular.ttf".to_string(),
"Enable Debugging".to_string(),
20,
TextJustify::Left,
true,
);
check_widget.set_point(CONFIG_ORIGIN, 20, 540);
check_widget.set_size(CONFIG_BODY_SIZE, 500, 28);
check_widget.set_color(CONFIG_TEXT_COLOR, [0.0, 0.0, 0.0, 1.0]);
self.pushrod.borrow_mut().add_widget_to_parent_by_name(
"MainContainerWidget",
"DebugCheck1",
Box::new(check_widget),
);
let mut text_widget1 = TextWidget::new(
"assets/OpenSans-Regular.ttf".to_string(),
"Current Widget: 0".to_string(),
20,
TextJustify::Left,
);
text_widget1.set_point(CONFIG_ORIGIN, 20, 570);
text_widget1.set_size(CONFIG_BODY_SIZE, 500, 28);
text_widget1.set_color(CONFIG_TEXT_COLOR, [0.0, 0.0, 0.0, 1.0]);
self.pushrod.borrow_mut().add_widget_to_parent_by_name(
"MainContainerWidget",
"DebugText1",
Box::new(text_widget1),
);
let mut text_widget2 = TextWidget::new(
"assets/OpenSans-Regular.ttf".to_string(),
"".to_string(),
20,
TextJustify::Left,
);
text_widget2.set_point(CONFIG_ORIGIN, 20, 600);
text_widget2.set_size(CONFIG_BODY_SIZE, 500, 28);
text_widget2.set_color(CONFIG_TEXT_COLOR, [0.0, 0.0, 0.0, 1.0]);
self.pushrod.borrow_mut().add_widget_to_parent_by_name(
"MainContainerWidget",
"DebugText2",
Box::new(text_widget2),
);
}Trait Implementations
sourceimpl Drawable for CheckboxWidget
impl Drawable for CheckboxWidget
sourcefn draw(&mut self, c: Context, g: &mut GlGraphics, clip: &DrawState)
fn draw(&mut self, c: Context, g: &mut GlGraphics, clip: &DrawState)
Draws the
Widget’s contents. Only gets called if the Widget is in invalidated
state. Provides a modified Context object that has an origin of 0x0 in drawing
space for the draw routine. Also provides a mut G2d object against which to draw,
and a clip, which is automatically set to provide a clipping area for the Widget. If
the Widget draws outside of the clipped bounds, that will not be drawn on the
screen.sourcefn draw_disabled(
&mut self,
c: Context,
size: Size,
g: &mut GlGraphics,
clip: &DrawState,
)
fn draw_disabled( &mut self, c: Context, size: Size, g: &mut GlGraphics, clip: &DrawState, )
Internal method that is used to draw a box around the
Widget when in disabled state.
You can override this method, should you choose to, so that the disabled state appears
differently in your application. It is safe to leave this alone.sourcefn draw_with_offset(
&mut self,
c: Context,
g: &mut GlGraphics,
clip: &DrawState,
point_offset: Point,
)
fn draw_with_offset( &mut self, c: Context, g: &mut GlGraphics, clip: &DrawState, point_offset: Point, )
Draws an object at an offset on the screen. This is a convenience method that is used
by other
Widgets that contain multiple widgets. (See CheckboxWidget and
ImageButtonWidget for good examples of this use.)sourceimpl InjectableCustomEvents for CheckboxWidget
impl InjectableCustomEvents for CheckboxWidget
sourcefn inject_custom_event(&mut self, _widget_id: i32) -> Option<CallbackEvent>
fn inject_custom_event(&mut self, _widget_id: i32) -> Option<CallbackEvent>
Injects an event into the run loop. This can be a timer event, a refresh event, or
whatever the
Widget wants to inject. These should be custom events, not system
events. This method only gets called if injects_events returns true.sourceimpl InjectableSystemEvents for CheckboxWidget
impl InjectableSystemEvents for CheckboxWidget
sourcefn inject_system_event(&mut self) -> Option<CallbackEvent>
fn inject_system_event(&mut self) -> Option<CallbackEvent>
Part of the main loop that queries the
Widget for any system-level events that should
be injected into the PushrodCallbackEvents trait, and not handled by the top-level
run loop. This sends out messages that are bypassed from being used by the Run Loop,
so be very careful. Use this for sending things like custom messages (such as a Widget
move or Widget resize message, which is irrelevant to the run loop.)sourceimpl Widget for CheckboxWidget
impl Widget for CheckboxWidget
sourcefn config(&mut self) -> &mut Configurable
fn config(&mut self) -> &mut Configurable
Retrieves the
Configurable object for this Widget. All Widget implementations
must provide this. (See the CanvasWidget implementation.)sourcefn set_config(&mut self, config: u8, config_value: Config)
fn set_config(&mut self, config: u8, config_value: Config)
Master config setter - use convenience methods.
sourcefn handle_event(
&mut self,
injected: bool,
event: CallbackEvent,
) -> Option<CallbackEvent>
fn handle_event( &mut self, injected: bool, event: CallbackEvent, ) -> Option<CallbackEvent>
Custom handler to receive an event. Any
Widget that implements this does so to handle
top-level GUI events, such as a mouse entering or exiting the bounds of this Widget.
If the injected flag is set, it indicates that the event supplied was generate by
a Widget, and not by the run loop.sourcefn handles_events(&mut self) -> bool
fn handles_events(&mut self) -> bool
Indicates to the run loop whether or not the
Widget handles system-generated events.fn set_widget_id(&mut self, widget_id: i32)
fn get_widget_id(&mut self) -> i32
sourcefn get_injectable_custom_events(&mut self) -> &mut dyn InjectableCustomEvents
fn get_injectable_custom_events(&mut self) -> &mut dyn InjectableCustomEvents
Retrieves the
InjectableCustomEvents trait of this class, which is responsible for
injecting custom events when appropriate. Injecting system events is used with the
InjectableSystemEvents, and things like mouse clicks and widget clicks are used
with the handle_event block. This code is used to inject events that are not
triggered by other events in the system.sourcefn get_injectable_system_events(&mut self) -> &mut dyn InjectableSystemEvents
fn get_injectable_system_events(&mut self) -> &mut dyn InjectableSystemEvents
Retrieves the trait for injecting system events. Only use this if your
Widget injects
custom system-level events that the top-level application needs to use. Anything other
than that should be ignored completely.sourcefn get_drawable(&mut self) -> &mut dyn Drawable
fn get_drawable(&mut self) -> &mut dyn Drawable
Retrieves the
Drawable functionality of this Widget.sourcefn invalidate(&mut self)
fn invalidate(&mut self)
Indicates that a
Widget object needs to be repainted.sourcefn clear_invalidate(&mut self)
fn clear_invalidate(&mut self)
Clears the invalidation flag. Set this when the
draw function completes. Otherwise,
this Widget object may be continuously repainted.sourcefn is_invalidated(&mut self) -> bool
fn is_invalidated(&mut self) -> bool
Indicates whether or not a
Widget needs to be repainted.sourcefn get_config(&mut self, config: u8) -> Option<&Config>
fn get_config(&mut self, config: u8) -> Option<&Config>
Master config getter - use convenience methods.
sourcefn set_point(&mut self, config: u8, x: i32, y: i32)
fn set_point(&mut self, config: u8, x: i32, y: i32)
Sets a point value for a configuration key.
sourcefn set_numeric(&mut self, config: u8, value: u64)
fn set_numeric(&mut self, config: u8, value: u64)
Sets a numeric value for a configuration key.
sourcefn set_toggle(&mut self, config: u8, flag: bool)
fn set_toggle(&mut self, config: u8, flag: bool)
Sets a toggle value for a configuration key.
sourcefn injects_custom_events(&mut self) -> bool
fn injects_custom_events(&mut self) -> bool
If this
Widget provides custom injected events that are generated outside of the
handle_event loop, indicate true. Only override if necessary. (See TimerWidget
for reference.)sourcefn is_drawable(&mut self) -> bool
fn is_drawable(&mut self) -> bool
Describes whether or not the
Widget returns a Drawable trait. This function is called each
time a frame is refreshed, so if there is no Drawable available, this function could
serve as a way to indicate a frame tick. Only override this to set it to false if your
Widget does not draw anything on the screen.sourcefn injects_system_events(&mut self) -> bool
fn injects_system_events(&mut self) -> bool
Indicates to the run loop whether or not a
Widget injects system-level events.Auto Trait Implementations
impl Freeze for CheckboxWidget
impl RefUnwindSafe for CheckboxWidget
impl Send for CheckboxWidget
impl Sync for CheckboxWidget
impl Unpin for CheckboxWidget
impl UnwindSafe for CheckboxWidget