Module pushrod::widget::config

source ·
Configurable definition, used by Widget objects to store configuration settings.

Structs

Enums

  • Configuration object type - allows configurations to be set using Piston, Pushrod, or native types.

Constants