[][src]Module pushrod::widget::container_widget

Simple container component: used for grouping widgets in a top-level container object, typically a Dialog Box in other libraries.

Structs

ContainerWidget

A ContainerWidget is a CanvasWidget that only contains a backing color.

Traits

ContainerWidgetTrait

Containers that handle resize events should implement this trait when extending a ContainerWidget, as the container widget itself needs to resize its known contained widgets according to the rules of the container bounds.