[][src]Trait pushrod::widget::container_widget::ContainerWidgetTrait

pub trait ContainerWidgetTrait {
    fn handle_resize(&mut self, _size: Size) { ... }
}

Containers that handle resize events should implement this trait when extending a ContainerWidget, as the container widget itself needs to resize its known contained widgets according to the rules of the container bounds.

Provided methods

fn handle_resize(&mut self, _size: Size)

Loading content...

Implementors

impl ContainerWidgetTrait for ContainerWidget[src]

fn handle_resize(&mut self, _size: Size)[src]

Loading content...