[−][src]Struct pushrod::widget::image_button_widget::ImageButtonWidget
Draws an image in a box with specified Text next to it.
Methods
impl ImageButtonWidget[src]
pub fn new(
font_name: String,
text: String,
image_name: String,
font_size: u32,
justify: TextJustify
) -> Self[src]
font_name: String,
text: String,
image_name: String,
font_size: u32,
justify: TextJustify
) -> Self
Constructor. Requires the name of the font, the text to display, the image name to display, the size of the font,
and the font justification when rendered. Images are loaded from the assets/
directory.