Module pushrod::widget::image_widget
source · Expand description
Image component: draws an image on the screen in png, jpg or gif formats.
Structs
- Draws an image.
Image component: draws an image on the screen in png, jpg or gif formats.