[][src]Module pushrod::widget::push_button_widget

Push Button component: draws a clickable box on the screen, triggering an on_clicked callback when appropriate.

Structs

PushButtonWidget

This is the PushButtonWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.