Module pushrod::widget::radio_button_widget

source ·
Radio button component: only allows a single item to be selected in a group.

Structs

  • Draws a radio button with only one object that can be selected at any one time within a group. Generates a WidgetSelected event when an object has been selected within the group. Also generates an internal UnselectRadioButtons event, which should not be handled - this is only used by RadioButtonWidget objects.