Struct pushrod::widget::radio_button_widget::RadioButtonWidget
source · pub struct RadioButtonWidget { /* private fields */ }Expand description
Draws a radio button with only one object that can be selected at any one time within a group.
Generates a WidgetSelected event when an object has been selected within the group. Also
generates an internal UnselectRadioButtons event, which should not be handled - this is only
used by RadioButtonWidget objects.
Implementations
sourceimpl RadioButtonWidget
impl RadioButtonWidget
sourcepub fn new(
font_name: String,
text: String,
font_size: u32,
justify: TextJustify,
selected: bool,
) -> Self
pub fn new( font_name: String, text: String, font_size: u32, justify: TextJustify, selected: bool, ) -> Self
Constructor. Requires the name of the font, the text to display, the image name to display, the size of the font,
the font justification when rendered, and a selected pre-set state. Images are
loaded from the assets/ directory.