Module pushrod::widget::text_widget

source ·
Text component: draws text on the screen with an adjustable text, font size, color, and font name.

Structs

Enums

  • Enumeration identifying the justification of the text to be drawn, as long as the bounds of the object allow for it.