Enum pushrod::widget::text_widget::TextJustify
source · pub enum TextJustify {
Left,
Center,
Right,
}Expand description
Enumeration identifying the justification of the text to be drawn, as long as the bounds of the object allow for it.
Variants
Left
Left-justified text.
Center
Center-justified text: (total width - text width) / 2
Right
Right-justified text: (total width - text width)