[−][src]Struct pushrod::widget::text_widget::TextWidget
Draws a block of text.
Fields
desired_width: i32Methods
impl TextWidget[src]
pub fn new(
font_name: String,
text: String,
font_size: u32,
justify: TextJustify
) -> Self[src]
font_name: String,
text: String,
font_size: u32,
justify: TextJustify
) -> Self
Constructor. Requires the name of the font, the text to display, the size of the font, and the font justification when rendered.