Module pushrod::widget::timer_widget
source · Expand description
Timer component: triggers a callback after a certain amount of time.
Structs
- Creates a timer that can be used to generate callbacks based on a timeout. When a timeout has been reached, a
TimerTriggeredevent is generated. Set the timer timeout in milliseconds by settingCONFIG_TIMER_TIMEOUTvalues.