[][src]Struct pushrod::widget::timer_widget::TimerWidget

pub struct TimerWidget { /* fields omitted */ }

Creates a timer that can be used to generate callbacks based on a timeout. When a timeout has been reached, a TimerTriggered event is generated. Set the timer timeout in milliseconds by setting CONFIG_TIMER_TIMEOUT values.

Timer timeouts are triggered on a per-refresh basis, so if the FPS of the screen for the main window is set to 30 FPS, the timer will only receive a tick every 1/30th of a second. If you need higher resolution timers, consider using threads.

Methods

impl TimerWidget[src]

pub fn new() -> Self[src]

Constructor.

pub fn on_tick<F>(&mut self, callback: F) where
    F: FnMut(&mut TimerWidget) + 'static, 
[src]

Assigns the callback closure that will be used when a timer tick is triggered.