Module pushrod::widget::toggle_button_widget
source · Expand description
Toggle Button component: draws a clickable box on the screen, triggering an on_selected callback
where appropriate.
Structs
- Draws a toggleable button on the screen. The selected state of this object can be set ahead of time by toggling
CONFIG_SELECTED. ThisWidgetgeneratesWidgetSelectedevents when toggled. The toggle state can be retrieved by reading theCONFIG_SELECTEDstate of thisWidget.