[][src]Module pushrod::widget::widget

Base component and UI Components (Widget) library. These components are used for on-screen interactions between the user and the application.

Structs

BaseWidget

This is the BaseWidget, which contains a top-level widget for display. It does not contain any special logic other than being a base for a display layer.

Traits

Widget

Implementable trait that is used by every Widget. These are the public methods, and a function may override them.