[−][src]Struct pushrod::widget::widget::CanvasWidget
This is the CanvasWidget, which contains a top-level widget for display. It does
not contain any special logic other than being a base for a display layer.
Example usage:
let mut base_widget = CanvasWidget::new(); base_widget.set_origin(100, 100); base_widget.set_size(200, 200); base_widget.set_color([0.5, 0.5, 0.5, 1.0]); // Widgets must be boxed, as they are trait objects. let widget_id = prod.widget_store.add_widget(Box::new(base_widget)); eprintln!("Added widget: ID={}", widget_id); let mut base_widget_2 = CanvasWidget::new(); base_widget_2.set_origin(125, 125); base_widget_2.set_size(100, 100); base_widget_2.set_color([0.75, 0.75, 0.75, 1.0]); // Add the second widget to the top level base widget. let widget_id_2 = prod.widget_store.add_widget_to_parent(Box::new(base_widget_2), widget_id);
Methods
impl CanvasWidget[src]
Implementation of the constructor for the CanvasWidget. Creates a new base widget
that can be positioned anywhere on the screen.