Module widgets

Module widgets 

widgets is a core rendering library used by Pushrod, containing the default set of Widgets.

Modules

checkbox_widget
This is a CheckboxWidget, which acts similar to a ToggleButtonWidget, but does not fill the box with a black/white color on select. Rather, it enables/disables a checkbox to indicate a selected option.
grid_widget
This is a GridWidget that contains a number of Widgets that can be repositioned and snapped to a grid coordinate.
image_button_widget
This is an ImageButtonWidget, which acts like a PushButtonWidget, drawing an image on the left-hand side of the bounds of the Widget, then the text next to it, justified left.
image_widget
This is an ImageWidget, which draws an Image in a clipped area.
list_widget
This is a ListWidget that displays a list of items in a selectable box.
progress_widget
This is a ProgressWidget, which draws a progress bar.
push_button_widget
This is a PushButtonWidget, which draws text in a Widget that can be clicked. It triggers an on_click callback when the button is clicked.
slider_widget
This is a SliderWidget that displays a slider in a movable area, which changes values from min to max bounds.
tab_bar_widget
text_widget
This is a TextWidget, which draws text in a clipped area.
tile_widget
This is a TileWidget that displays an image and some text below it, with a display change when the widget is hovered over by a mouse enter event. This is mainly used in conjunction with the ToolbarWidget, which contains a list of TileWidgets
timer_widget
This is a TimerWidget, which times out after a specified duration, triggering a callback after the timeout is exceeded.
toggle_button_widget
This is a ToggleButtonWidget, which acts similar to a PushButtonWidget except that it triggers on_toggle callbacks when the state changes.