Module checkbox_widget

Module checkbox_widget 

This is a CheckboxWidget, which acts similar to a ToggleButtonWidget, but does not fill the box with a black/white color on select. Rather, it enables/disables a checkbox to indicate a selected option.

Structs

CheckboxWidget
This is the storage object for the CheckboxWidget. It stores the config, properties, callback registry.

Type Aliases

OnToggleCallbackType
This is the callback type that is used when an on_toggle callback is triggered from this Widget.