Module grid_widget

Module grid_widget 

This is a GridWidget that contains a number of Widgets that can be repositioned and snapped to a grid coordinate.

Structs

GridWidget
This is the storage object for the GridWidget. It stores the config, properties, callback registry.