Module image_button_widget

Module image_button_widget 

This is an ImageButtonWidget, which acts like a PushButtonWidget, drawing an image on the left-hand side of the bounds of the Widget, then the text next to it, justified left.

Structs

ImageButtonWidget
This is the storage object for the ImageButtonWidget. It stores the config, properties, callback registry.

Type Aliases

OnClickCallbackType
This is the callback type that is used when an on_click callback is triggered from this Widget.