Module image_widget

Module image_widget 

This is an ImageWidget, which draws an Image in a clipped area.

Structs

ImageWidget
This is the storage object for the ImageWidget. It stores the config, properties, callback registry, the image name, and a scale flag.