Module list_widget

Module list_widget 

This is a ListWidget that displays a list of items in a selectable box.

Structs

ListWidget
This is the storage object for the ListWidget. It stores the config, properties, callback registry.

Type Aliases

OnSelectedCallbackType
This is the callback type that is used when an on_selected callback is triggered from this Widget.