Module tab_bar_widget

Module tab_bar_widget 

Structs

TabBarWidget
This is the storage object for the TabBarWidget. It stores the config, properties, callback registry, tab items, and other storage values for internal rendering.

Type Aliases

OnTabSelectedCallbackType
This is the callback type that is used when an on_tab_selected callback is triggered from this Widget. Returns a number indicating the tab that was selected, starting from 0.