[][src]Module pushrod::widgets::tab_widget

This is a TabWidget, which acts as a container for ToggleButtonWidgets that can act as a control for a tab-controlled container.

Structs

TabWidget

This is the storage object for the TabWidget. It stores the config, properties, callback registry, and the tab widget IDs.