Module text_widget

Module text_widget 

This is a TextWidget, which draws text in a clipped area.

Structs

TextWidget
This is the storage object for the TextWidget. It stores the config, properties, callback registry, the font name, style, size, justification, and text message.

Enums

TextJustify
This enum is used by the TextWidget, which controls the justification of the text being rendered within the bounds of the Widget.