[−][src]Struct pushrod::widgets::text_widget::TextWidget
This is the storage object for the TextWidget. It stores the config, properties, callback registry,
the font name, style, size, justification, and text message.
Implementations
impl TextWidget[src]
Creates a new TextWidget, which draws a unit of text on the screen, given the specified font,
size, justification, and layout coordinates.
pub fn new(
font_name: String,
font_style: FontStyle,
font_size: i32,
justification: TextJustify,
msg: String,
x: i32,
y: i32,
w: u32,
h: u32
) -> Self[src]
font_name: String,
font_style: FontStyle,
font_size: i32,
justification: TextJustify,
msg: String,
x: i32,
y: i32,
w: u32,
h: u32
) -> Self
Creates a new TextWidget object. Requires the name of the font (the path to the font file),
the style of font (sdl2::ttf::FontStyle), the size in pixels of the font, the TextJustify
layout of the font, the message to display, and the x, y, w, h coordinates of the text.