Module tile_widget

Module tile_widget 

This is a TileWidget that displays an image and some text below it, with a display change when the widget is hovered over by a mouse enter event. This is mainly used in conjunction with the ToolbarWidget, which contains a list of TileWidgets

Structs

TileWidget
This is the storage object for the TileWidget. It stores the config, properties, callback registry.

Type Aliases

OnClickedCallbackType
This is the callback type that is used when an on_click callback is triggered from this Widget. Returns a flag indicating the selected state - toggled on or off.