Module pushrod::core::callbacks

source ·
This is a per-widget event store that is used to call an event handler when an event is triggered.

Enums

  • These are the different types of events that can be triggered. Any other callback events should be extended in this enum definition.

Traits

  • This is the callback event class that is used to handle events that are produced when a widget is interacted with in the Pushrod Run Loop. This callback is triggered when an event happens either in the main GUI, or within a GUI object.