[][src]Module pushrod::core::callbacks

This is a per-widget callback store that is used to call closures when an event is triggered.

Enums

CallbackEvent

These are the different types of events that can be triggered. Any other callback events should be extended in this enum definition.

Traits

PushrodCallbackEvents

This is the callback event class that is used to handle events that are produced when a widget is interacted with in the Pushrod Run Loop.