[−][src]Module pushrod::core::callbacks
This is a per-widget callback store that is used to call closures when an event is triggered.
Structs
| CallbackStore | This is the |
Enums
| CallbackTypes | This is an enumerated type that is used to store numerous variations of callbacks that can
be used within the |
Constants
| CALLBACK_BUTTON_DOWN | Index for button click callback, used by |
| CALLBACK_KEY_PRESSED | Index for keyboard event callback, used by |
| CALLBACK_MOUSE_ENTERED | Index for mouse entered callback, used by |
| CALLBACK_MOUSE_EXITED | Index for mouse exited callback, used by |
| CALLBACK_MOUSE_MOVED | Index for mouse moved callback, used by |
| CALLBACK_MOUSE_SCROLLED | Index for mouse scrolled callback, used by |
| CALLBACK_WINDOW_FOCUSED | Index for window focused callback, used by |
| CALLBACK_WINDOW_RESIZED | Index for window resized callback, used by |
Type Definitions
| BlankCallback | Callback type that takes no input. |
| BoolCallback | Callback type that accepts a boolean. |
| ButtonCallback | Callback type that accepts a widget ID and a button code. |
| KeyCallback | Callback type that accepts a widget ID, a key code, and its down/up button keypress state. |
| PointCallback | Callback type that accepts a widget ID and a |
| SingleCallback | Callback type that accepts a widget ID. |
| SizeCallback | Callback type that accepts a widget ID and a |