[][src]Module pushrod::core::callbacks

This is a per-widget callback store that is used to call closures when an event is triggered.

Structs

CallbackStore

This is the CallbackStore that is used to store a list of CallbackTypes that are triggered when an action occurs on a Widget.

Enums

CallbackTypes

This is an enumerated type that is used to store numerous variations of callbacks that can be used within the Widget system. This is written such that the CallbackTypes enum can be added to/extended as necessary.

Constants

CALLBACK_KEY_PRESSED
CALLBACK_MOUSE_ENTERED

Index for mouse entered callback, used by Widget internally. Refers to a CallbackTypes::SingleCallback callback.

CALLBACK_MOUSE_EXITED

Index for mouse exited callback, used by Widget internally. Refers to a CallbackTypes::SingleCallback callback.

CALLBACK_MOUSE_MOVED

Index for mouse moved callback, used by Widget internally. Refers to a CallbackTypes::PointCallback callback.

CALLBACK_MOUSE_SCROLLED

Index for mouse scrolled callback, used by Widget internally. Refers to a CallbackTypes::PointCallback callback.

Type Definitions

BlankCallback

Callback type that takes no input parameters.

KeyCallback
PointCallback

Callback type that accepts a widget ID and a Point on the screen as its input parameter.

SingleCallback

Callback type that accepts a widget ID as its input parameter.