[−][src]Module pushrod::core::callbacks
This is a per-widget callback store that is used to call closures when an event is triggered.
Structs
| CallbackStore | This is the |
Enums
| CallbackTypes | This is an enumerated type that is used to store numerous variations of callbacks that can
be used within the |
Constants
| CALLBACK_MOUSE_ENTERED | Index for mouse entered callback, used by |
| CALLBACK_MOUSE_EXITED | Index for mouse exited callback, used by |
| CALLBACK_MOUSE_MOVED | Index for mouse moved callback, used by |
| CALLBACK_MOUSE_SCROLLED | Index for mouse scrolled callback, used by |
Type Definitions
| PointCallback | |
| SingleCallback |