[−][src]Enum pushrod::core::callbacks::CallbackEvent
These are the different types of events that can be triggered. Any other callback events should be extended in this enum definition.
Variants
MouseEnteredIndicates a mouse entered the bounds of a Widget. Contains the ID of the Widget that was
affected.
Fields of MouseEntered
widget_id: i32MouseExitedIndicates a mouse exited the bounds of a Widget. Contains the ID of the Widget that was
affected.
Fields of MouseExited
widget_id: i32MouseScrolledIndicates that the scroll wheel was moved inside a Widget. Contains the ID of the
Widget that had the mouse scroll action, and the point in the direction of the scroll,
along with the amount of points the mouse scroll moved.
Fields of MouseScrolled
MouseMovedIndicates that a mouse moved within the bounds of a Widget. Contains the ID of the
Widget that was affected.
Fields of MouseMoved
KeyPressedIndicates that a keyboard key was pressed/released inside the bounds of a Widget. Contains
the ID of the Widget that received the keypress, along with the Key value, and any
associated Button modifier states.
Fields of KeyPressed
WindowResizedIndicates that the main application window was resized. Contains the Size of the new
bounds.
Fields of WindowResized
size: SizeWindowFocusedIndicates whether or not focus was gained or lost for the main application. Contains a
boolean flag indicating focus: true is focused, false if lost.
Fields of WindowFocused
flag: boolMouseButtonDownIndicates that a mouse button was pressed within the bounds of a Widget. Contains the
ID of the Widget, along with the Button that was clicked.
Fields of MouseButtonDown
widget_id: i32MouseButtonUpInsideIndicates that a mouse button was released within the bounds of a Widget. Contains
the ID of the Widget, along with the Button that was released.
Fields of MouseButtonUpInside
widget_id: i32MouseButtonUpOutsideIndicates that a mouse button was released outside of the bounds of a Widget. Contains
the ID of the Widget, along with the Button that was released.
Fields of MouseButtonUpOutside
widget_id: i32WidgetClickedIndicates that a mouse button triggered a click action within a Widget. Contains the
ID of the Widget, along with the Button that was used to indicate the click action.
Fields of WidgetClicked
widget_id: i32WidgetSelectedIndicates that a Widget's selected state has been toggled. Contains the ID of the
Widget that was toggled, along with the mouse Button that was clicked, and the
final selected state of the widget.
Fields of WidgetSelected
TimerTriggeredIndicates that a timer timeout has been triggered. Contains the ID of the Widget that was
affected.
Fields of TimerTriggered
widget_id: i32UnselectRadioButtonsIndicates that a group of RadioButtonWidget objects has been deselected. Contains the
ID of the Widget that was unselected, along with the group ID.
Fields of UnselectRadioButtons