[−][src]Enum pushrod::core::callbacks::CallbackEvent
These are the different types of events that can be triggered. Any other callback events should be extended in this enum definition.
Variants
MouseEnteredFields of MouseEntered
widget_id: i32MouseExitedFields of MouseExited
widget_id: i32MouseScrolledFields of MouseScrolled
MouseMovedFields of MouseMoved
KeyPressedFields of KeyPressed
WindowResizedFields of WindowResized
size: SizeWindowFocusedFields of WindowFocused
flag: boolMouseButtonDownFields of MouseButtonDown
widget_id: i32MouseButtonUpInsideFields of MouseButtonUpInside
widget_id: i32MouseButtonUpOutsideFields of MouseButtonUpOutside
widget_id: i32WidgetClickedFields of WidgetClicked
widget_id: i32WidgetSelectedFields of WidgetSelected
TimerTriggeredFields of TimerTriggered
widget_id: i32UnselectRadioButtonsFields of UnselectRadioButtons