[−][src]Struct pushrod::core::callbacks::CallbackStore
This is the CallbackStore that is used to store a list of CallbackTypes that are
triggered when an action occurs on a Widget.
Methods
impl CallbackStore[src]
The actual class implementation of the CallbackStore. This is primarily stored within the
Widget class, and its usage looks something similar to the following code:
let mut cs = CallbackStore::new();
cs.put(CALLBACK_MOUSE_MOVED,
CallbackTypes::PointCallback { callback: Box::new(|widget_id, point| {
eprintln!("Callback for widget {} resulted in point at {} x {}",
widget_id, point.x, point.y);
})
});
// And, to call the callback to run it:
match cs.get(CALLBACK_MOUSE_MOVED) {
CallbackTypes::PointCallback { callback } =>
callback(12, Point { x: 16, y: 24 }),
_ => eprintln!("Unsupported callback for ID {}!", CALLBACK_MOUSE_MOVED),
}This is an example of how it would be used in the Widget callbacks. User-specified
callbacks will likely be much simpler than this.
pub fn new() -> Self[src]
pub fn put(&mut self, id: u32, func: CallbackTypes)[src]
pub fn get(&mut self, id: u32) -> &CallbackTypes[src]