[−][src]Trait pushrod::core::callbacks::PushrodCallbackEvents
This is the callback event class that is used to handle events that are produced when a widget is interacted with in the Pushrod Run Loop. This callback is triggered when an event happens either in the main GUI, or within a GUI object.