[−][src]Trait pushrod::core::callbacks::PushrodCallbackEvents
This is the callback event class that is used to handle events that are produced when a widget is interacted with in the Pushrod Run Loop.
This is the callback event class that is used to handle events that are produced when a widget is interacted with in the Pushrod Run Loop.
fn handle_event(&mut self, event: CallbackEvent, widget_store: &mut WidgetStore)