Module pushrod::core::layout_manager
source · Expand description
This provides a layout manager to the WidgetStore, which contains a list of known widgets
by ID and their point offsets within the layouts.
Structs
- This structure is sent to the
LayoutManagerat the timedo_layoutis called. This structure contains the layout of all of theWidgets by origin, the sizes of each of theWidgets, and their positions relative to the layout manager. Thewidget_positionsdo not need to be actual positions in points - they can be used to denote the positions within the layout they are to occur - for instance, 0x0, 0x1, 1x0 and 1x1 in a layout, if the layout were a grid layout. - This class defines the spacing rules and the padding for the layout manager. The layout manager must take the rules and honor it during the layout process.
Traits
- Describes the behavior of a
LayoutManager. Layout Managers do not actually manage anyWidgetobjects by themselves, they only apply the rules of theLayoutManagerPaddingcoordinates, and the size of theLayoutManagerthat is available.