[−][src]Struct pushrod::core::layout_manager::LayoutManagerCoordinates
This structure is sent to the LayoutManager at the time do_layout is called. This
structure contains the layout of all of the Widgets by origin, the sizes of each of the
Widgets, and their positions relative to the layout manager. The widget_positions do not
need to be actual positions in points - they can be used to denote the positions within the
layout they are to occur - for instance, 0x0, 0x1, 1x0 and 1x1 in a layout, if the layout were
a grid layout.
Fields
widget_origins: Vec<Point>widget_sizes: Vec<Size>widget_positions: Vec<Point>Trait Implementations
impl PartialEq<LayoutManagerCoordinates> for LayoutManagerCoordinates[src]
fn eq(&self, other: &LayoutManagerCoordinates) -> bool[src]
fn ne(&self, other: &LayoutManagerCoordinates) -> bool[src]
impl Default for LayoutManagerCoordinates[src]
fn default() -> LayoutManagerCoordinates[src]
impl Clone for LayoutManagerCoordinates[src]
fn clone(&self) -> LayoutManagerCoordinates[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more
impl Debug for LayoutManagerCoordinates[src]