Struct pushrod::core::layout_manager::LayoutManagerCoordinates
source · pub struct LayoutManagerCoordinates {
pub widget_origins: Vec<Point>,
pub widget_sizes: Vec<Size>,
pub widget_positions: Vec<Point>,
}Expand description
This structure is sent to the LayoutManager at the time do_layout is called. This
structure contains the layout of all of the Widgets by origin, the sizes of each of the
Widgets, and their positions relative to the layout manager. The widget_positions do not
need to be actual positions in points - they can be used to denote the positions within the
layout they are to occur - for instance, 0x0, 0x1, 1x0 and 1x1 in a layout, if the layout were
a grid layout.
Fields
widget_origins: Vec<Point>widget_sizes: Vec<Size>widget_positions: Vec<Point>Trait Implementations
sourceimpl Clone for LayoutManagerCoordinates
impl Clone for LayoutManagerCoordinates
sourcefn clone(&self) -> LayoutManagerCoordinates
fn clone(&self) -> LayoutManagerCoordinates
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for LayoutManagerCoordinates
impl Debug for LayoutManagerCoordinates
sourceimpl Default for LayoutManagerCoordinates
impl Default for LayoutManagerCoordinates
sourcefn default() -> LayoutManagerCoordinates
fn default() -> LayoutManagerCoordinates
Returns the “default value” for a type. Read more
sourceimpl PartialEq for LayoutManagerCoordinates
impl PartialEq for LayoutManagerCoordinates
sourcefn eq(&self, other: &LayoutManagerCoordinates) -> bool
fn eq(&self, other: &LayoutManagerCoordinates) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for LayoutManagerCoordinates