Struct pushrod::core::layout_manager::LayoutManagerPadding
source · pub struct LayoutManagerPadding {
pub left: i32,
pub right: i32,
pub top: i32,
pub bottom: i32,
pub spacing: i32,
}Expand description
This class defines the spacing rules and the padding for the layout manager. The layout manager must take the rules and honor it during the layout process.
Fields
left: i32right: i32top: i32bottom: i32spacing: i32Trait Implementations
sourceimpl Clone for LayoutManagerPadding
impl Clone for LayoutManagerPadding
sourcefn clone(&self) -> LayoutManagerPadding
fn clone(&self) -> LayoutManagerPadding
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for LayoutManagerPadding
impl Debug for LayoutManagerPadding
sourceimpl Default for LayoutManagerPadding
impl Default for LayoutManagerPadding
sourcefn default() -> LayoutManagerPadding
fn default() -> LayoutManagerPadding
Returns the “default value” for a type. Read more
sourceimpl PartialEq for LayoutManagerPadding
impl PartialEq for LayoutManagerPadding
sourcefn eq(&self, other: &LayoutManagerPadding) -> bool
fn eq(&self, other: &LayoutManagerPadding) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for LayoutManagerPadding