[−][src]Struct pushrod::core::main::Pushrod
This structure is returned when instantiating a new Pushrod main object.
Fields
widget_store: RefCell<WidgetStore>This is the WidgetStore object that is used to store the Widget list in the current
display stack.
drawing_texture: DrawingTextureMethods
impl Pushrod[src]
Pushrod implementation. Create a Pushrod::new( PistonWindow ) object to create a new
main loop. Only one of these should be set for the entire application runtime.
pub fn new(window: GlfwWindow) -> Self[src]
Pushrod Object Constructor. Takes in a single OpenGL configuration type.
pub fn add_widget(&mut self, name: &str, widget: Box<dyn Widget>) -> i32[src]
Convenience method that adds a Widget to the GUI display stack.
pub fn add_layout_manager(&mut self, manager: Box<dyn LayoutManager>) -> i32[src]
Convenience method that adds a LayoutManager to the layout management stack.
pub fn add_widget_to_layout_manager(
&mut self,
name: &str,
widget: Box<dyn Widget>,
manager_id: i32,
position: Point
) -> i32[src]
&mut self,
name: &str,
widget: Box<dyn Widget>,
manager_id: i32,
position: Point
) -> i32
Convenience method that adds a Widget to a LayoutManager by the manager's ID and
the positioning of the Widget.
pub fn add_widget_to_parent(
&mut self,
name: &str,
widget: Box<dyn Widget>,
parent_id: i32
) -> i32[src]
&mut self,
name: &str,
widget: Box<dyn Widget>,
parent_id: i32
) -> i32
Convenience method that adds a Widget to a parent by its ID. This guarantees a refresh
if the top level parent becomes invalidated.
pub fn add_widget_to_parent_by_name(
&mut self,
parent_name: &str,
name: &str,
widget: Box<dyn Widget>
) -> i32[src]
&mut self,
parent_name: &str,
name: &str,
widget: Box<dyn Widget>
) -> i32
Convenience method that adds a Widget to a parent by the parent's name.
pub fn run(&mut self, event_handler: &mut dyn PushrodCallbackEvents)[src]
This is the main run loop for Pushrod. A run loop requires the use of an assigned
PushrodCallbackEvents event handler. This is how all communications take place when
an action occurs within the GUI window.