[][src]Struct pushrod::core::main::Pushrod

pub struct Pushrod {
    pub widget_store: RefCell<WidgetStore>,
    // some fields omitted
}

This structure is returned when instantiating a new Pushrod main object.

Fields

widget_store: RefCell<WidgetStore>

This is the WidgetStore object that is used to store the Widget list in the current display stack.

Methods

impl Pushrod[src]

Pushrod implementation. Create a Pushrod::new( PistonWindow ) object to create a new main loop. Only one of these should be set for the entire application runtime.

pub fn new(window: PistonWindow) -> Self[src]

Pushrod Object Constructor. Takes in a single OpenGL configuration type.

pub fn get_factory(&mut self) -> &mut GfxFactory[src]

Retrieves the window GfxFactory factory object for graphics and font textures.

pub fn add_widget(&mut self, name: &str, widget: Box<dyn Widget>) -> i32[src]

Convenience method that adds a Widget to the GUI display stack.

pub fn add_widget_to_parent(
    &mut self,
    name: &str,
    widget: Box<dyn Widget>,
    parent_id: i32
) -> i32
[src]

Convenience method that adds a Widget to a parent by its ID. This guarantees a refresh if the top level parent becomes invalidated.

pub fn run(&mut self, event_handler: &mut dyn PushrodCallbackEvents)[src]

This is the main run loop for Pushrod. A run loop requires the use of an assigned PushrodCallbackEvents event handler. This is how all communications take place when an action occurs within the GUI window.