Contains geometric shape representations: Point and Size, representing a point on
the screen within a window, and the size of an object. (This may change to Piston’s
representations.)
Structs
- Structure identifying a point on the screen by X and Y coordinates. X and Y coordinates are represented from the upper left-hand corner of the base object.
- Structure identifying a size of an object by W (width) and H (height), respectively. Other systems may use “width” and “height” as nomenclature, however, we wanted to keep naming consistent.
Functions
- Convenience method to create a
Pointof origin, defined as an X and Y coordinate of 0. - Convenience method to convert floating point X and Y positions to a graphical
Point. - Convenience method to create a new
Point. - Convenience method to create a non-existent size, defined as a width and height of 0.