Module pushrod::core::vertical_layout_manager

source ·
This provides a VerticalLayoutManager object, which accepts Widget objects, and resizes and repositions them according to the height of the manager. Widgets are repositioned in the VerticalLayoutManager’s top level widget equally.

Structs