Module pushrod::core::widget_store
source · Expand description
This is a cache that is used to store Widget objects for a Pushrod run loop. Each
Pushrod object that is created contains its own set of Widget objects, stored here.
Structs
- This is a container object that stores a
Widget, assigns a name, aWidgetID, and its parent. - This is the
WidgetStore, which contains a list ofWidgetobjects for a GUI window.