[−][src]Module pushrod::core::widget_store
This is a cache that is used to store Widget objects for a Pushrod run loop. Each
Pushrod object that is created contains its own set of Widget objects, stored here.
Structs
| WidgetContainer | This is a container object that stores a |
| WidgetStore | This is the |