[][src]Module pushrod::core::widget_store

This is a cache that is used to store Widget objects for a Pushrod run loop. Each Pushrod object that is created contains its own set of Widget objects, stored here.

Structs

WidgetContainer

This is a container object, used for storing the Widget trait object, and the parent relationship for the added Widget. Only the widget is public. Widget objects do not need to have a child relationship, only parent objects are traversed. A parent object of 0, or itself, indicates that the parent is self.

WidgetStore

This is the WidgetStore, which is used to store Widget objects for a Pushrod management object.