[−][src]Enum pushrod::event::event::PushrodEvent
Enumeration types for different PushrodEvents, translated from the underlying OS.
Variants
MouseEventMouse event contains a point to where the mouse was moved.
Fields of MouseEvent
point: PointMouseDownEventContains the button that was pressed.
Fields of MouseDownEvent
MouseUpEventCOntains the button that was released.
Fields of MouseUpEvent
MouseScrollEventContains the direction in which the mouse scroll event took place. X movement in a positive direction indicates movement to the right, where negative is to the left. Y movement in a positive direction indicates downward movement, negative is upward.
Fields of MouseScrollEvent
point: PointAuto Trait Implementations
impl Send for PushrodEvent
impl Sync for PushrodEvent