pub type OnExitCallbackType = Option<Box<dyn FnMut(&mut Engine) -> bool>>;Expand description
This function is called when when the application requests to quit. It accepts the currently
running engine, and the return value will indicate whether or not to quit. Returning a true
tells the engine to quit, false otherwise. If this function is not set, the application
will quit when asked.
Aliased Type
pub enum OnExitCallbackType {
None,
Some(Box<dyn FnMut(&mut Engine) -> bool>),
}