This is a layout manager description module, describing rules for Layout managers to be used
in the system, and having Widgets added to them.
Structs
- Layout
Position - This is a structure that describes the position of a
Widgetwithin itsLayout.XandYcoordinates are not given as physical positions on the screen, rather, their position in theLayoutmatrix.
Traits
- Layout
- This is a
Layouttrait that is used by theEngineservice, which stores a list ofWidgets, their positions (based on matrix coordinates), and an entry point to trigger the layout compute action.