[−][src]Struct pushrod::render::layout_cache::LayoutContainer
This is a container object that stores a Layout object, and its ID.
Fields
layout: RefCell<Box<dyn Layout>>Methods
impl LayoutContainer[src]
This is an implementation that allows for creation of a LayoutContainer.
pub fn new(layout: Box<dyn Layout>, layout_id: i32) -> Self[src]
Creates a new LayoutContainer-wrapped Layout object.
pub fn get_layout_id(&self) -> i32[src]
Retrieves the current layout ID.