This is the Widget and BaseWidget definitions for Widget objects to be defined by the
pushrod project, and other crates that may define or create their own Widgets.
Structs
- Base
Widget - This is an example top-level
Widgetobject that is used to draw a background and a border of specified colors.COLOR_BASEdetermines the background fill color, and theCOLOR_BORDERdetermines the color of the border. The width of the border is controlled by theget_config().border_widthproperty.
Traits
- Widget
- This trait is shared by all
Widgetobjects that have a presence on the screen. Functions that must be implemented are documented in the trait.