Widget library used for on-screen UI interaction. This is a core set of Widget
objects that are used to allow users to interact with an application. Contains a core set
of widgets that can be used and extended.
Modules
- Box component: draws a box on the screen with adjustable border color and width.
- Checkbox component: draws a selectable checkbox with text.
Configurabledefinition, used byWidgetobjects to store configuration settings.- Image button component: draws an image inside a push button widget.
- Image component: draws an image on the screen in
png,jpgorgifformats. - Progress component: draws a progress meter widget.
- Push Button component: draws a clickable box on the screen, triggering an
on_clickedcallback when appropriate. - Radio button component: only allows a single item to be selected in a group.
- Text component: draws text on the screen with an adjustable text, font size, color, and font name.
- Timer component: triggers a callback after a certain amount of time.
- Toggle Button component: draws a clickable box on the screen, triggering an
on_selectedcallback where appropriate. - Base component and UI Components (Widget) library. These components are used for on-screen interactions between the user and the application.