[−][src]Module pushrod::widget
Widget library used for on-screen UI interaction. This is a core set of Widget
objects that are used to allow users to interact with an application. Contains a core set
of widgets that can be used and extended.
Modules
| box_widget | Box component: draws a box on the screen with adjustable border color and width. |
| checkbox_widget | Checkbox component: draws a selectable checkbox with text. |
| config |
|
| container_widget | Simple container component: used for grouping widgets in a top-level container object, typically a Dialog Box in other libraries. |
| image_button_widget | Image button component: draws an image inside a push button widget. |
| image_widget | Image component: draws an image on the screen in |
| progress_widget | Progress component: draws a progress meter widget. |
| push_button_widget | Push Button component: draws a clickable box on the screen, triggering an |
| radio_button_widget | Radio button component: only allows a single item to be selected in a group. |
| text_widget | Text component: draws text on the screen with an adjustable text, font size, color, and font name. |
| timer_widget | Timer component: triggers a callback after a certain amount of time. |
| toggle_button_widget | Toggle Button component: draws a clickable box on the screen, triggering an |
| widget | Base component and UI Components (Widget) library. These components are used for on-screen interactions between the user and the application. |