[−][src]Struct pushrod::widget::box_widget::BoxWidget
A BoxWidget is a CanvasWidget with a bounding box. Takes two additional options:
CONFIG_BORDER_WIDTHspecifies the width of the border to be drawn in pixels.CONFIG_BORDER_COLORspecifies the color of the border to be drawn.
Methods
impl BoxWidget[src]