[][src]Struct pushrod::widget::box_widget::BoxWidget

pub struct BoxWidget { /* fields omitted */ }

This is the BoxWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.

Methods

impl BoxWidget[src]

Implementation of the constructor for the BaseWidget. Creates a new base widget that can be positioned anywhere on the screen.

pub fn new() -> Self[src]

pub fn set_border_color(&mut self, color: Color)[src]

Sets the border color for this widget.

pub fn get_border_color(&mut self) -> Color[src]

Retrieves the border color of this widget. Defaults to black color [0.0, 0.0, 0.0, 1.0] if not set.

pub fn set_border_thickness(&mut self, thickness: u8)[src]

Sets the thickness of the border for this widget.

pub fn get_border_thickness(&mut self) -> u8[src]

Retrieves the border thickness of this widget. Defaults to 1 if not set.

pub fn set_border(&mut self, color: Color, thickness: u8)[src]

Helper function that sets both the color of the border and the thickness at the same time.