[][src]Module pushrod::widget::checkbox_widget

Checkbox component: draws a selectable checkbox with text.

Structs

CheckboxWidget

This is the CheckboxWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.