Configurable definition, used by Widget objects to store configuration settings.
Structs
- Structure containing the configuration
HashMap.
Enums
- Configuration object type - allows configurations to be set using
Piston,Pushrod, or native types.
Constants
Sizeof aWidget, set byConfig::Size.- Color of the border of a
Widget, set byConfig::Color. - Width of the border of a
Widget, set byConfig::Numeric. - Text to be displayed in a
Widget, set byConfig::Text. - Indicates whether or not a
Widgetneeds to be redrawn, set byConfig::Toggle. - Color of the body of a
Widget, set byConfig::Color. - Origin of a
Widget, set byConfig::Point. - Progress indicator from 0-100, set by
Config::Numeric. - Secondary color (body, image, etc.) in a
Widget, set byConfig::Color. - Indicates whether or not a
Widgethas been toggled/selected, set byConfig::Toggle. - Color of the text to be drawn in a
Widget, set byConfig::Color. - Indicates whether or not a timer is enabled, set by
Config::Toggle. - Indicates whether or not a timeout has occurred, set by
Config::Toggle. - Indicates whether or not a
Widgetis disabled, set byConfig::Toggle. - Identifies the
Widget’s grouping ID forRadioButtonWidget, set byConfig::Numeric. - Indicates whether or not a
Widgethas been hidden, set byConfig::Toggle.