[][src]Module pushrod::widget::config

Configurable definition, used by Widget objects to store configuration settings.

Structs

Configurable

Structure containing the configuration HashMap.

Enums

Config

Configuration object type - allows configurations to be set using Piston, Pushrod, or native types.

Constants

CONFIG_BODY_SIZE

Size of a Widget, set by Config::Size.

CONFIG_BORDER_COLOR

Color of the border of a Widget, set by Config::Color.

CONFIG_BORDER_WIDTH

Width of the border of a Widget, set by Config::Numeric.

CONFIG_DISPLAY_TEXT

Text to be displayed in a Widget, set by Config::Text.

CONFIG_INVALIDATE

Indicates whether or not a Widget needs to be redrawn, set by Config::Toggle.

CONFIG_MAIN_COLOR

Color of the body of a Widget, set by Config::Color.

CONFIG_ORIGIN

Origin of a Widget, set by Config::Point.

CONFIG_PROGRESS

Progress indicator from 0-100, set by Config::Numeric.

CONFIG_SECONDARY_COLOR

Secondary color (body, image, etc.) in a Widget, set by Config::Color.

CONFIG_SELECTED

Indicates whether or not a Widget has been toggled/selected, set by Config::Toggle.

CONFIG_TEXT_COLOR

Color of the text to be drawn in a Widget, set by Config::Color.

CONFIG_TIMER_ENABLED

Indicates whether or not a timer is enabled, set by Config::Toggle.

CONFIG_TIMER_TIMEOUT

Indicates whether or not a timeout has occurred, set by Config::Toggle.

CONFIG_WIDGET_DISABLED

Indicates whether or not a Widget is disabled, set by Config::Toggle.

CONFIG_WIDGET_GROUP_ID

Identifies the Widget's grouping ID for RadioButtonWidget, set by Config::Numeric.

CONFIG_WIDGET_HIDDEN

Indicates whether or not a Widget has been hidden, set by Config::Toggle.

CONFIG_WIDGET_ID

Specifies the Widget ID, set by Config::Numeric.