[−][src]Module pushrod::widget::config
Configurable definition, used by Widget objects to store configuration settings.
Structs
| Configurable | Structure containing the configuration |
Enums
| Config | Configuration object type - allows configurations to be set using |
Constants
| CONFIG_BODY_SIZE |
|
| CONFIG_BORDER_COLOR | Color of the border of a |
| CONFIG_BORDER_WIDTH | Width of the border of a |
| CONFIG_DISPLAY_TEXT | Text to be displayed in a |
| CONFIG_INVALIDATE | Indicates whether or not a |
| CONFIG_MAIN_COLOR | Color of the body of a |
| CONFIG_ORIGIN | Origin of a |
| CONFIG_PROGRESS | Progress indicator from 0-100, set by |
| CONFIG_SECONDARY_COLOR | Secondary color (body, image, etc.) in a |
| CONFIG_SELECTED | Indicates whether or not a |
| CONFIG_TEXT_COLOR | Color of the text to be drawn in a |
| CONFIG_TIMER_ENABLED | Indicates whether or not a timer is enabled, set by |
| CONFIG_TIMER_TIMEOUT | Indicates whether or not a timeout has occurred, set by |
| CONFIG_WIDGET_DISABLED | Indicates whether or not a |
| CONFIG_WIDGET_GROUP_ID | Identifies the |
| CONFIG_WIDGET_HIDDEN | Indicates whether or not a |
| CONFIG_WIDGET_ID | Specifies the |