[][src]Module pushrod::widget::config

Configurable definition, used by Widget objects to store configuration settings.

Structs

BodySize

Physical size of the Widget.

BorderColor

Color of the border for the BoxWidget and any Widget objects that contain a border.

BorderWidth

Width (in pixels) of the border for the BoxWidget or any Widget objects that contain a border.

Configurable

Default Configurable object, created for each struct represented in the impl_configurable! macro.

Invalidate

Existence of this object indicates that a Widget needs to be redrawn.

MainColor

Color of the body of the Widget.

Origin

Origin Point at which a Widget exists on the display window.

SecondaryColor

Color of a secondary object to be drawn within a Widget.

TextColor

Color of text to be displayed in a TextWidget.

Traits

ConfigKey