[−][src]Module pushrod::widget::config
Configurable definition, used by Widget objects to store configuration settings.
Structs
| BodySize | Physical size of the |
| BorderColor | Color of the border for the |
| BorderWidth | Width (in pixels) of the border for the |
| Configurable | Default Configurable object, created for each struct represented in the
|
| Invalidate | Existence of this object indicates that a |
| MainColor | Color of the body of the |
| Origin | Origin |
| TextColor |
|
Traits
| ConfigKey |