[][src]Module pushrod::widget::config

Configurable definition, used by Widget objects to store configuration settings.

Structs

Configurable

This structure is used for the configuration store of Widget settings. It contains its own structure internally, so all that is used inside extended Widget objects is a simple instantiation of a new Configurable object as part of your extension.

Enums

WidgetConfig

Enumeration data type containing storage areas for each configuration object.

Constants

CONFIG_BORDER_WIDTH

Config entry key for retrieving the widget's border width.

CONFIG_COLOR

Config entry key for retrieving the widget's color.

CONFIG_COLOR_BORDER

Config entry key for retrieving the widget's border color.

CONFIG_INVALIDATE

Config entry key for invalidated object (invalidated means "requires screen refresh")

CONFIG_ORIGIN

Config entry key for retrieving the Point of origin.

CONFIG_SIZE

Config entry key for retrieving the Size of the widget.

Type Definitions

ConfigKey

A programmatic type identifying the type of key (and most importantly, size) that is used for storing configuration values for a Widget in the config HashMap.