[−][src]Module pushrod::widget::config
Configurable definition, used by Widget objects to store configuration settings.
Structs
| Configurable | This structure is used for the configuration store of |
Enums
| WidgetConfig | Enumeration data type containing storage areas for each configuration object. |
Constants
| CONFIG_BORDER_WIDTH | Config entry key for retrieving the widget's border width. |
| CONFIG_COLOR | Config entry key for retrieving the widget's color. |
| CONFIG_COLOR_BORDER | Config entry key for retrieving the widget's border color. |
| CONFIG_INVALIDATE | Config entry key for invalidated object (invalidated means "requires screen refresh") |
| CONFIG_ORIGIN | Config entry key for retrieving the |
| CONFIG_SIZE | Config entry key for retrieving the |
Type Definitions
| ConfigKey | A programmatic type identifying the type of key (and most importantly, size) that is used
for storing configuration values for a |