[−][src]Module pushrod::widget::container_widget
Simple container component: used for grouping widgets in a top-level container object, typically a Dialog Box in other libraries.
Structs
| ContainerWidget | A |
Traits
| ContainerWidgetTrait | Containers that handle resize events should implement this trait when extending
a |