[−][src]Trait pushrod::widget::container_widget::ContainerWidgetTrait
Containers that handle resize events should implement this trait when extending
a ContainerWidget, as the container widget itself needs to resize its known
contained widgets according to the rules of the container bounds.