pub struct ImageButtonWidget { /* private fields */ }
Draws an image in a box with specified Text next to it.

Implementations

source

impl ImageButtonWidget

source

pub fn new( font_name: String, text: String, image_name: String, font_size: u32, justify: TextJustify, ) -> Self

Constructor. Requires the name of the font, the text to display, the image name to display, the size of the font, and the font justification when rendered. Images are loaded from the assets/ directory.

Examples found in repository?
examples/simple.rs (lines 928-934)
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
    fn add_powered_by(&mut self) {
        let mut image_widget = ImageButtonWidget::new(
            "assets/OpenSans-Regular.ttf".to_string(),
            "Powered By Rust!".to_string(),
            "rust-512x512.jpg".to_string(),
            18,
            TextJustify::Left,
        );

        image_widget.set_point(CONFIG_ORIGIN, 570, 580);
        image_widget.set_size(CONFIG_BODY_SIZE, 220, 48);
        image_widget.set_color(CONFIG_TEXT_COLOR, [0.0, 0.0, 0.0, 1.0]);
        image_widget.set_numeric(CONFIG_BORDER_WIDTH, 1);
        image_widget.set_color(CONFIG_BORDER_COLOR, [0.0, 0.0, 0.0, 1.0]);

        self.pushrod.borrow_mut().add_widget_to_parent_by_name(
            "MainContainerWidget",
            "RustImageButton",
            Box::new(image_widget),
        );
    }