[][src]Struct pushrod::widget::push_button_widget::PushButtonWidget

pub struct PushButtonWidget { /* fields omitted */ }

This is the PushButtonWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.

Example usage: IN PROGRESS

Methods

impl PushButtonWidget[src]

Implementation of the constructor for the PushButtonWidget.

pub fn new(
    factory: &mut GfxFactory,
    font_name: String,
    text: String,
    font_size: u32,
    justify: TextJustify
) -> Self
[src]