[][src]Struct pushrod::widget::push_button_widget::PushButtonWidget

pub struct PushButtonWidget { /* fields omitted */ }

This is the PushButtonWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.

Example usage:

   let mut button_widget = PushButtonWidget::new(prod.get_factory(),
       "OpenSans-Regular.ttf".to_string(),
       "Button".to_string(),
       20,
       TextJustify::Center,
   );

   button_widget.set_origin(100, 100);
   button_widget.set_size(200, 200);
   button_widget.set_border_color([0.0, 0.0, 0.0, 1.0]);
   button_widget.set_border_thickness(3);
   button_widget.on_clicked(Box::new(|| {
       eprintln!("Button Widget Clicked!");
   }));

   // (OR)

   button_widget.set_border([0.0, 0.0, 0.0, 1.0], 3);

Methods

impl PushButtonWidget[src]

Implementation of the constructor for the PushButtonWidget.

pub fn new(
    factory: &mut GfxFactory,
    font_name: String,
    text: String,
    font_size: u32,
    justify: TextJustify
) -> Self
[src]

pub fn set_text(&mut self, text: String)[src]

Sets the border color for this widget.

pub fn set_text_color(&mut self, color: Color)[src]

Sets the color of the text for this Widget.

pub fn get_text_color(&mut self) -> Color[src]

Retrieves the color of the text for this Widget. Defaults to black if not set.

pub fn set_border_color(&mut self, color: Color)[src]

Sets the border color for this widget.

pub fn get_border_color(&mut self) -> Color[src]

Retrieves the border color of this widget. Defaults to black color [0.0, 0.0, 0.0, 1.0] if not set.

pub fn set_border_thickness(&mut self, thickness: u8)[src]

Sets the thickness of the border for this widget.

pub fn get_border_thickness(&mut self) -> u8[src]

Retrieves the border thickness of this widget. Defaults to 1 if not set.

pub fn set_border(&mut self, color: Color, thickness: u8)[src]

Helper function that sets both the color of the border and the thickness at the same time.

pub fn on_clicked(&mut self, callback: MutableBlankCallback)[src]

This is the callback that is triggered when a mouse triggers the button_up_inside event of the main PushButtonWidget.