Module pushrod::widget::radio_button_widget
source · Expand description
Radio button component: only allows a single item to be selected in a group.
Structs
- Draws a radio button with only one object that can be selected at any one time within a group. Generates a
WidgetSelectedevent when an object has been selected within the group. Also generates an internalUnselectRadioButtonsevent, which should not be handled - this is only used byRadioButtonWidgetobjects.