[][src]Module pushrod::widget::radio_button_widget

Radio button component: only allows a single item to be selected in a group.

Structs

RadioButtonWidget

This is the RadioButtonWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.