[][src]Struct pushrod::widget::radio_button_widget::RadioButtonWidget

pub struct RadioButtonWidget { /* fields omitted */ }

This is the RadioButtonWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.

Example usage: IN PROGRESS

Methods

impl RadioButtonWidget[src]

Implementation of the constructor for the RadioButtonWidget.

pub fn new(
    factory: &mut GfxFactory,
    font_name: String,
    text: String,
    font_size: u32,
    justify: TextJustify,
    selected: bool
) -> Self
[src]