Module pushrod::widget::text_widget
source · Expand description
Text component: draws text on the screen with an adjustable text, font size, color, and font name.
Structs
- Draws a block of text.
Enums
- Enumeration identifying the justification of the text to be drawn, as long as the bounds of the object allow for it.