[−][src]Module pushrod::widget::text_widget
Text component: draws text on the screen with an adjustable text, font size, color, and font name.
Structs
| TextWidget | This is the |
Enums
| TextJustify | This |
Text component: draws text on the screen with an adjustable text, font size, color, and font name.
| TextWidget | This is the |
| TextJustify | This |