[][src]Module pushrod::widget::text_widget

Text component: draws text on the screen with an adjustable text, font size, color, and font name.

Structs

TextWidget

This is the TextWidget, which draws a line of text on the screen. This structure contains no accessable objects, they are all internal to TextWidget's implementation.

Enums

TextJustify

This enum specifies the desired justification of the text to be drawn.