[−][src]Struct pushrod::widget::text_widget::TextWidget
This is the TextWidget, which draws a line of text on the screen. This structure contains
no accessable objects, they are all internal to TextWidget's implementation.
Example usage: IN PROGRESS
Methods
impl TextWidget[src]
Implementation of the constructor for the TextWidget. Creates a new text object to be
displayed on the screen, given a font name, font size, and text message.
pub fn new(
factory: &mut GfxFactory,
font_name: String,
text: String,
font_size: u32,
justify: TextJustify
) -> Self[src]
factory: &mut GfxFactory,
font_name: String,
text: String,
font_size: u32,
justify: TextJustify
) -> Self
Creates a new TextWidget object, requiring the current PistonWindow's factory object
(which can be cloned), the name of the font (filename in the assets directory), the
text to display, the font size in which to use, and the desired text justification
strategy.
pub fn draw_text(&mut self, c: Context, g: &mut G2d, clip: &DrawState)[src]
Function to draw the text. Generates a context transformation to display the text based on the point of origin's X and Y coordinates. Since the text is drawn upwards from the point of origin, the starting point is the lower left-hand corner of the widget. (This may change based on text justification, and other optional padding, once padding is introduced.)