[−][src]Struct pushrod::widget::text_widget::TextWidget
This is the TextWidget, which draws a line of text on the screen. This structure contains
no accessable objects, they are all internal to TextWidget's implementation.
Methods
impl TextWidget[src]
Implementation of the constructor for the TextWidget. Creates a new text object to be
displayed on the screen, given a font name, font size, and text message.
pub fn new(
factory: GfxFactory,
font_name: String,
text: String,
font_size: u32
) -> Self[src]
factory: GfxFactory,
font_name: String,
text: String,
font_size: u32
) -> Self
Creates a new TextWidget object, requiring the current PistonWindow's factory object
(which can be cloned), the name of the font (filename in the assets directory), the
text to display, and the font size in which to use.
pub fn set_text_color(&mut self, color: Color)[src]
Sets the color of the text for this Widget.
pub fn get_text_color(&mut self) -> Color[src]
Retrieves the color of the text for this Widget.
Defaults to black if not set.
pub fn set_text(&mut self, text: String)[src]
Changes the text, redraws after change.
pub fn draw_text(&mut self, c: Context, g: &mut G2d)[src]
Function to draw the text. Generates a context transformation to display the text based on the point of origin's X and Y coordinates. Since the text is drawn upwards from the point of origin, the starting point is the lower left-hand corner of the widget. (This may change based on text justification, and other optional padding, once padding is introduced.)