[−][src]Struct pushrod::widget::timer_widget::TimerWidget
Creates a timer that can be used to generate callbacks based on a timeout. When a timeout
has been reached, a TimerTriggered event is generated. Set the timer timeout in
milliseconds by setting CONFIG_TIMER_TIMEOUT values.
Timer timeouts are triggered on a per-refresh basis, so if the FPS of the screen for the main window is set to 30 FPS, the timer will only receive a tick every 1/30th of a second. If you need higher resolution timers, consider using threads.
Methods
impl TimerWidget[src]