[−][src]Struct pushrod::widget::timer_widget::TimerWidget
This is the TimerWidget. It contains no base widget, it only contains a start and end
time,
Example usage: IN PROGRESS
Methods
impl TimerWidget[src]
Implementation of the constructor for the TimerWidget. Timer widgets are not accessible
on the screen, so they have an origin of 0x0 and width of 0x0.
The timer provides a simple way to call a callback function after a certain amount of time has passed. Upon instantiation, the timer is enabled.
Here are a few limitations of the timer as it currently stands:
- Timer cannot be paused; it is enabled or disabled, and the timer resets when enabled.
- Timer is called when the screen refreshes, so slower FPS settings will affect the timer.
pub fn new() -> Self[src]
Constructor, creates a new TimerWidget struct with an empty timeout function.