[][src]Struct pushrod::widget::timer_widget::TimerWidget

pub struct TimerWidget { /* fields omitted */ }

This is the TimerWidget. It contains no base widget, it only contains a start and end time,

Methods

impl TimerWidget[src]

Implementation of the constructor for the TimerWidget. Timer widgets are not accessible on the screen, so they have an origin of 0x0 and width of 0x0.

The timer provides a simple way to call a callback function after a certain amount of time has passed. Upon instantiation, the timer is enabled.

Here are a few limitations of the timer as it currently stands:

  • Timer cannot be paused; it is enabled or disabled, and the timer resets when enabled.
  • Timer is called when the screen refreshes, so slower FPS settings will affect the timer.

pub fn new() -> Self[src]

Constructor, creates a new TimerWidget struct with an empty timeout function.

pub fn set_enabled(&mut self, enabled: bool)[src]

Enables or disables the timer. When disabled, the timer will not initiate the callback function. When re-enabled, the initiation time resets, so the timer will reset back to zero, effectively resetting the entire timer.

pub fn on_timeout(&mut self, timeout_function: Box<dyn Fn()>)[src]

Sets the closure function for the timer when a timeout has been triggered. This closure needs to be Boxed.

pub fn set_timeout(&mut self, timeout: u64)[src]

Sets the timeout in milliseconds for this timer. Will trigger a call to the function set in on_timeout when triggered, and will continue to call that function until this timer is disabled by using self.set_enabled(false).