[][src]Module pushrod::widget::toggle_button_widget

Toggle Button component: draws a clickable box on the screen, triggering an on_selected callback where appropriate.

Structs

ToggleButtonWidget

This is the ToggleButtonWidget, which contains a top-level widget for display, overriding the draw method to draw the base widget and the border for this box.