widgets is a core rendering library used by Pushrod, containing the default set of Widgets.
Modules
- checkbox_
widget - This is a
CheckboxWidget, which acts similar to aToggleButtonWidget, but does not fill the box with a black/white color on select. Rather, it enables/disables a checkbox to indicate a selected option. - grid_
widget - This is a
GridWidgetthat contains a number ofWidgets that can be repositioned and snapped to a grid coordinate. - image_
button_ widget - This is an
ImageButtonWidget, which acts like aPushButtonWidget, drawing an image on the left-hand side of the bounds of theWidget, then the text next to it, justified left. - image_
widget - This is an
ImageWidget, which draws an Image in a clipped area. - list_
widget - This is a
ListWidgetthat displays a list of items in a selectable box. - progress_
widget - This is a
ProgressWidget, which draws a progress bar. - push_
button_ widget - This is a
PushButtonWidget, which draws text in aWidgetthat can be clicked. It triggers anon_clickcallback when the button is clicked. - slider_
widget - This is a
SliderWidgetthat displays a slider in a movable area, which changes values from min to max bounds. - tab_
bar_ widget - text_
widget - This is a
TextWidget, which draws text in a clipped area. - tile_
widget - This is a
TileWidgetthat displays an image and some text below it, with a display change when the widget is hovered over by a mouse enter event. This is mainly used in conjunction with theToolbarWidget, which contains a list ofTileWidgets - timer_
widget - This is a
TimerWidget, which times out after a specified duration, triggering a callback after the timeout is exceeded. - toggle_
button_ widget - This is a
ToggleButtonWidget, which acts similar to aPushButtonWidgetexcept that it triggerson_togglecallbacks when the state changes.