This is an ImageButtonWidget, which acts like a PushButtonWidget, drawing an image on the left-hand
side of the bounds of the Widget, then the text next to it, justified left.
Structs
- Image
Button Widget - This is the storage object for the
ImageButtonWidget. It stores the config, properties, callback registry.
Type Aliases
- OnClick
Callback Type - This is the callback type that is used when an
on_clickcallback is triggered from thisWidget.