This is an ImageWidget, which draws an Image in a clipped area.
Structs
- Image
Widget - This is the storage object for the
ImageWidget. It stores the config, properties, callback registry, the image name, and a scale flag.
This is an ImageWidget, which draws an Image in a clipped area.
ImageWidget. It stores the config, properties, callback registry,
the image name, and a scale flag.