[][src]Module pushrod::widgets::image_widget

This is an ImageWidget, which draws an Image in a clipped area.

Structs

ImageWidget

This is the storage object for the TextWidget. It stores the config, properties, callback registry, the font name, style, size, justification, and text message.