This is a ListWidget that displays a list of items in a selectable box.
Structs
- List
Widget - This is the storage object for the
ListWidget. It stores the config, properties, callback registry.
Type Aliases
- OnSelected
Callback Type - This is the callback type that is used when an
on_selectedcallback is triggered from thisWidget.