This is a SliderWidget that displays a slider in a movable area, which changes values from min to
max bounds.
Structs
- Slider
Widget - This is the storage object for the
SliderWidget. It stores the config, properties, callback registry.
Enums
- Slider
Orientation - These are the possible slider orientations.
Type Aliases
- OnValue
Changed Callback Type - This is the callback type that is used when an
on_value_changedcallback is triggered from thisWidget.