[][src]Module pushrod::widgets::slider_widget

This is a SliderWidget that displays a slider in a movable area, which changes values from min to max bounds.

Structs

SliderWidget

This is the storage object for the SliderWidget. It stores the config, properties, callback registry.

Enums

SliderOrientation

These are the possible slider orientations.

Type Definitions

OnValueChangedCallbackType

This is the callback type that is used when an on_value_changed callback is triggered from this Widget.