Structs
- TabBar
Widget - This is the storage object for the
TabBarWidget. It stores the config, properties, callback registry, tab items, and other storage values for internal rendering.
Type Aliases
- OnTab
Selected Callback Type - This is the callback type that is used when an
on_tab_selectedcallback is triggered from thisWidget. Returns a number indicating the tab that was selected, starting from0.