[−][src]Struct pushrod::widgets::tab_widget::TabWidget
This is the storage object for the TabWidget. It stores the config, properties, callback registry,
and the tab widget IDs.
Implementations
impl TabWidget[src]
Creates a new ImageWidget, which draws an image in a supported image format for SDL2 at a specific
location on the screen. Requires the name of the image (the full path to the file), the position
within the widget (defined as ImagePosition), the xywh bounds, and whether or not the image is
scaled within the bounds of the Widget.
pub fn new(x: i32, y: i32, w: u32, h: u32) -> Self[src]
Creates a new instance of the ImageWidget object. Requires an image name (full path of the file),
image position (defined in ImagePosition), the xywh bounds of the Widget, and a scale flag.
If scaled is set to true, the image will be scaled within the Widget bounds, and the
ImagePosition will be ignored. Likewise, if set to false, the image will be displayed for
the size of the image, and will be placed in the bounds of the Widget based on the position
specified in the ImagePosition.